@@ -51,6 +51,11 @@ else:
     envvar='PACT_BROKER_PASSWORD',
     help='Password for Pact Broker basic authentication. Can also be specified'
          ' via the environment variable PACT_BROKER_PASSWORD')
+@click.option(
+    'token', '--pact-broker-token',
+    envvar='PACT_BROKER_TOKEN',
+    help='Bearer token for Pact Broker authentication. Can also be specified'
+         ' via the environment variable PACT_BROKER_TOKEN')
 @click.option(
     'header', '--custom-provider-header',
     envvar='CUSTOM_PROVIDER_HEADER',
@@ -79,7 +84,7 @@ else:
     default=False,
     help='Toggle verbose logging, defaults to False.')
 def main(pacts, base_url, pact_url, pact_urls, states_url,
-         states_setup_url, username, password, header, timeout,
+         states_setup_url, username, password, token, header, timeout,
          provider_app_version, publish_verification_results, verbose):
     """
     Verify one or more contracts against a provider service.
@@ -121,6 +126,7 @@ def main(pacts, base_url, pact_url, pact_urls, states_url,
         '--provider-states-setup-url': states_setup_url,
         '--broker-username': username,
         '--broker-password': password,
+        '--broker-token': token,
         '--custom-provider-header': header,
     }
     command = [VERIFIER_PATH]
